[![Downloads Total](https://pepy.tech/badge/vacefron-py)](https://pepy.tech/project/vacefron-py)
[![Downloads Month](https://pepy.tech/badge/vacefron-py/month)](https://pepy.tech/project/vacefron-py)
[![Downloads Week](https://pepy.tech/badge/vacefron-py/week)](https://pepy.tech/project/vacefron-py)
[![PyPi Version](https://img.shields.io/pypi/v/vacefron.py.svg)](https://pypi.python.org/pypi/vacefron.py/)

# VACEfron.py

A Wrapper for [vacefron.nl/api][base_url] written in Python.

## Requirements

- Python 3.8 or above
- aiohttp (python3 -m pip install -U aiohttp)

## Installation

Install the package by doing one of the following commands:

**Using pip (recommended)**:

- `pip install vacefron.py -U`
- `python -m pip install vacefron.py -U`

## Documentation

See the full and detailed [docs here][docs]

## Links

[API][base_url] | [Changelogs][changelog] | [Github][github] | [PyPi][pypi]

## Made by

This wrapper is made by **Soheab#6240**, DM me on Discord or join my server [here][discord_mine] for anything related to
this wrapper.

You can join VAC Efron's server [here][discord_vacefron] to suggest or report anything on the API.

[docs]: https://github.com/Soheab/vacefron.py/blob/master/docs.md
[changelog]: https://github.com/Soheab/vacefron.py/blob/master/changelog.md
[base_url]: https://vacefron.nl/api/
[github]: https://github.com/Soheab/vacefron.py
[pypi]: https://pypi.org/project/vacefron.py/
[discord_vacefron]: https://discord.gg/xJ2HRxZ
[discord_mine]: https://discord.gg/yCzcfju


